  class CreateRoleDocumentSchema < ActiveRecord::Migration[5.0]
    def self.up
      create_table :role_documents do |t|
        t.string :name, null: false
        t.string :description

        # allow null on CRNs because of system defined role docs
        t.string :customer_crn, null: true
        t.string :created_by_crn, null: true
        t.string :updated_by_crn, null: true

        t.boolean :system_defined, default: false
        t.boolean :is_deleted, default: false

        t.timestamps
      end

      create_table :permissions do |t|
        t.string :action, null: false
        t.string :subject, null: false
        t.index [:action, :subject],
                unique: true,
                name: "idx_action_subject"
      end

      create_join_table :role_documents, :permissions do |t|
        t.index [:role_document_id, :permission_id],
                unique: true,
                name: "idx_role_documents_permissions"
      end
    end

    def self.down
      drop_table :role_documents_permissions
      drop_table :permissions
      drop_table :role_documents
    end
  end
